[Commits] [SCM] claws branch, master, updated. 3.13.2-49-g701a0ba
mones at claws-mail.org
mones at claws-mail.org
Fri Feb 19 19:22:20 CET 2016
The branch, master has been updated
via 701a0babe91bb8e11544113a3f3748782d589868 (commit)
from d1c40b332d9bb908df7694d19a60b2319a2a00fc (commit)
Summary of changes:
src/plugins/python/python_plugin.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
- Log -----------------------------------------------------------------
commit 701a0babe91bb8e11544113a3f3748782d589868
Author: Ricardo Mones <ricardo at mones.org>
Date: Fri Feb 19 19:21:50 2016 +0100
Fix a couple of typos
diff --git a/src/plugins/python/python_plugin.c b/src/plugins/python/python_plugin.c
index b34e589..0b0d813 100644
--- a/src/plugins/python/python_plugin.c
+++ b/src/plugins/python/python_plugin.c
@@ -634,7 +634,7 @@ done:
Py_XDECREF(meth_getvalue);
Py_XDECREF(result_getvalue);
- return retval ? retval : g_strdup("Unspecified error occured");
+ return retval ? retval : g_strdup("Unspecified error occurred");
}
static void log_func(const gchar *log_domain, GLogLevelFlags log_level, const gchar *message, gpointer user_data)
@@ -667,7 +667,7 @@ gint plugin_init(gchar **error)
/* The Python C API only offers to print an exception to sys.stderr. In order to catch it
* in a string, a StringIO object is created, to which sys.stderr can be redirected in case
* an error occured. */
inst_StringIO = get_StringIO_instance();
/* initialize Claws Mail Python module */
-----------------------------------------------------------------------
hooks/post-receive
@@ -667,7 +667,7 @@ gint plugin_init(gchar **error)
/* The Python C API only offers to print an exception to sys.stderr. In order to catch it
* in a string, a StringIO object is created, to which sys.stderr can be redirected in case
- * an error occured. */
+ * an error occurred. */
inst_StringIO = get_StringIO_instance();
/* initialize Claws Mail Python module */
--
Claws Mail
More information about the Commits
mailing list